<?php

namespace AuthEmailPassword\Http\Controllers;

use Inertia\Inertia;
use Inertia\Response;
use Illuminate\Http\Request;
use Illuminate\Http\RedirectResponse;

class LoginController
{
    public function index(): Response
    {
        return Inertia::render('Login/Index', [
            'login' => config('auth.defaults.login'),
        ]);
    }

    public function login(Request $request): RedirectResponse
    {
        $credentials = $request->only('email', 'password');

        $request->validate([
            'email' => [
                'required',
                'email',
            ],
            'password' => [
                'required',
            ],
        ], $credentials);

        if (auth()->attempt($credentials)) {
            return redirect()->intended(route('admin.event.index'));
        }

        return redirect()->back()->withErrors([
            'password' => trans('auth.failed'),
        ]);
    }

    public function logout(): RedirectResponse
    {
        auth()->logout();

        return redirect()->route('login.index');
    }
}
